#!/bin/bash
#
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

# this program kills the audit
WAIT_TIME=30
ps -ef | grep "org.apache.inlong.audit.node.Application" | grep "inlong-audit" | grep -v grep |awk '{print $2}' | xargs kill

echo "Stopping Audit Proxy application, please wait for $WAIT_TIME s. "

sleep $WAIT_TIME

ps -ef | grep "org.apache.inlong.audit.node.Application" | grep "inlong-audit" | grep -v grep |awk '{print $2}' | xargs kill -9